/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1994
 * Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the HP 4032 X terminal (aka Aptrex) keyboard.
 * By Mark Borges <mdb@cdc.noaa.gov>
 */

static const KeyCode hp4032x_codes [] = {

  /* Row 0 */
  18, 17,
  16, 24, 32, 40,
  48, 56, 64, 72,
  80, 88, 95, 103,
  96, 104, 107,
  0, 0, 0, 0,
/*  89, 90, 92, 102, */

  /* Row 1 */
  19, 20,
  23, 31, 39, 47, 46, 55, 63, 70, 71, 79, 78, 87, 94, 111,
  112, 119, 120,
  127, 128, 135, 141,

  /* Row 2 */
  21, 25,
  22, 30, 38, 45, 54, 53, 62, 69, 76, 77, 86, 93, 100, 101,
  109, 110, 118,
  117, 126, 134, 133,

  /* Row 3 */
  28, 33,
  29, 37, 36, 44, 52, 61, 60, 68, 75, 84, 85, 91, 99,
  116, 124, 125,

  /* Row 4 */
  41, 49,
  27, 35, 43, 42, 51, 59, 58, 67, 74, 82, 83, 98,
  108,
  114, 123, 131, 130,

  /* Row 5 */
  57, 65,
  26, 34, 73, 50, 81, 66, 97,
  106, 105, 115,
  121, 122
};
